@@ -480,7 +480,7 @@ def process_txt(raw_path,output,max_seq_length=512,eval_batch_size=30):
         #加载配置文件和模型参数
     model = BertForTokenClassification(config, num_labels=num_labels)
     if torch.cuda.is_available():
-        model.load_state_dict(torch.load(output_model_file,map_location='cuda'))
+        model.load_state_dict(torch.load(output_model_file,map_location='cuda'),False)
     else:
         model.load_state_dict(torch.load(output_model_file,map_location='cpu'))
 
